@@ -104,7 +104,8 @@ utils::globalVariables(c("%>%",
                          "AvExpInOtherClusters",
                          "X1",
                          "X2",
-                         "X3"))
+                         "X3",
+                         "hdf5r"))
 #########
 # F001.load10x.R | F001.R
 # F002.data.aggregation.R | F002.R
